-file("/usr/local/Cellar/erlang/18.2.1/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(nats_lexer).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/nats_lexer.xrl", 56).

-file("/usr/local/Cellar/erlang/18.2.1/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,_Tlen,_Ics1,_L1,_S1} ->
            string_cont(yysuf(Tcs, Alen), L0, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->       % Use last accept match
            token_cont(yysuf(Tcs, Alen1), L0, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            tokens_cont(yysuf(Tcs, Alen1), L0, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            skip_cont(yysuf(Tcs, Alen1), L1, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/nats_lexer.erl", 284).
yystate() -> 63.

yystate(66, [32|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, [9|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(66, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,66};
yystate(65, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(65, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(65, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,65};
yystate(64, [111|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [79|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 78 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 110 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 112 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,64};
yystate(63, [117|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [116|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [115|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [113|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [112|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [110|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [109|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [105|Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [85|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [84|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [83|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [81|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [80|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [78|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [77|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [73|Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [67|Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [9|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 33, C =< 42 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 66 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 68, C =< 72 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 74, C =< 76 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 86, C =< 104 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 106, C =< 108 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 118 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(63, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,63};
yystate(62, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(58, Ics, Line+1, Tlen+1, Action, Alen);
yystate(62, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,62};
yystate(61, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(60, [102|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [70|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 69 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 71, C =< 101 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 103 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(60, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,60};
yystate(59, [117|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [85|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 84 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 86, C =< 116 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 118 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(59, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,59};
yystate(58, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(57, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line};
yystate(56, [110|Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [78|Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 77 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 109 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 111 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(56, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,56};
yystate(55, [98|Ics], Line, Tlen, _, _) ->
    yystate(51, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [66|Ics], Line, Tlen, _, _) ->
    yystate(51, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 65 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 67, C =< 97 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 99 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(55, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,55};
yystate(54, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [9|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 8 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 14, C =< 31 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 33 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(54, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,54};
yystate(53, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line+1, Tlen+1, Action, Alen);
yystate(53, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,53};
yystate(52, [32|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 6, Tlen);
yystate(52, [9|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 6, Tlen);
yystate(52, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,52};
yystate(51, [32|Ics], Line, Tlen, _, _) ->
    yystate(47, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, [9|Ics], Line, Tlen, _, _) ->
    yystate(47, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(51, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,51};
yystate(50, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 14 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,50};
yystate(49, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line};
yystate(48, [32|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, [9|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(48, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,48};
yystate(47, [32|Ics], Line, Tlen, _, _) ->
    yystate(47, Ics, Line, Tlen+1, 8, Tlen);
yystate(47, [9|Ics], Line, Tlen, _, _) ->
    yystate(47, Ics, Line, Tlen+1, 8, Tlen);
yystate(47, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line,47};
yystate(46, [111|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [79|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 78 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 110 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 112 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,46};
yystate(45, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line+1, Tlen+1, Action, Alen);
yystate(45, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,45};
yystate(44, [103|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [71|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 70 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 72, C =< 102 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 104 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(44, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,44};
yystate(43, [110|Ics], Line, Tlen, _, _) ->
    yystate(39, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [78|Ics], Line, Tlen, _, _) ->
    yystate(39, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 77 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 109 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 111 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(43, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,43};
yystate(42, [110|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [78|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 77 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 109 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 111 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(42, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,42};
yystate(41, [13|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,41};
yystate(40, [115|Ics], Line, Tlen, _, _) ->
    yystate(44, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [83|Ics], Line, Tlen, _, _) ->
    yystate(44, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 82 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 84, C =< 114 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 116 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,40};
yystate(39, [115|Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [83|Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 82 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 84, C =< 114 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 116 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(39, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,39};
yystate(38, [110|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [78|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 77 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 109 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 111 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(38, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,38};
yystate(37, [107|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [75|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 74 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 76, C =< 106 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 108 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,37};
yystate(36, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(35, [117|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [85|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 84 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 86, C =< 116 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 118 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(35, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,35};
yystate(34, [101|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [69|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 68 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 100 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 102 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(34, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,34};
yystate(33, [111|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [79|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 78 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 110 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 112 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(33, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,33};
yystate(32, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line+1, Tlen+1, Action, Alen);
yystate(32, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,32};
yystate(31, [98|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [66|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 65 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 67, C =< 97 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 99 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(31, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,31};
yystate(30, [99|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [67|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 66 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 68, C =< 98 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 100 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(30, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,30};
yystate(29, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(17, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 14 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(29, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,29};
yystate(28, [13|Ics], Line, Tlen, _, _) ->
    yystate(32, Ics, Line, Tlen+1, 12, Tlen);
yystate(28, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(28, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(28, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,28};
yystate(27, [32|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, [9|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(27, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,27};
yystate(26, [116|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [84|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 83 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 115 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 117 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(26, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,26};
yystate(25, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(17, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [9|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 8 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 14, C =< 31 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 33 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(25, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,25};
yystate(24, [103|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [71|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 70 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 72, C =< 102 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 104 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(24, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,24};
yystate(23, [32|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 9, Tlen);
yystate(23, [9|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 9, Tlen);
yystate(23, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,23};
yystate(22, [32|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [9|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(22, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,22};
yystate(21, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(20, [110|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [78|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 77 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 109 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 111 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,20};
yystate(19, [117|Ics], Line, Tlen, _, _) ->
    yystate(15, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [85|Ics], Line, Tlen, _, _) ->
    yystate(15, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 84 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 86, C =< 116 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 118 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(19, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,19};
yystate(18, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line+1, Tlen+1, Action, Alen);
yystate(18, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,18};
yystate(17, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(21, Ics, Line+1, Tlen+1, Action, Alen);
yystate(17, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,17};
yystate(16, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line};
yystate(15, [98|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [66|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 65 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 67, C =< 97 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 99 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,15};
yystate(14, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line};
yystate(13, [32|Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, [9|Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(13, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,13};
yystate(12, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line+1, Tlen+1, Action, Alen);
yystate(12, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,12};
yystate(11, [32|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, [9|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(11, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,11};
yystate(10, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [9|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 8 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [C|Ics], Line, Tlen, Action, Alen) when C >= 14, C =< 31 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [C|Ics], Line, Tlen, Action, Alen) when C >= 33 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(10, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,10};
yystate(9, [114|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [82|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 81 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 83, C =< 113 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 115 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,9};
yystate(8, [13|Ics], Line, Tlen, _, _) ->
    yystate(12, Ics, Line, Tlen+1, 12, Tlen);
yystate(8, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(8, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 33 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(8, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,8};
yystate(7, [32|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 7, Tlen);
yystate(7, [9|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 7, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,7};
yystate(6, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 14 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(6, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,6};
yystate(5, [114|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [82|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 81 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 83, C =< 113 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 115 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,5};
yystate(4, [103|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [71|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 70 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 72, C =< 102 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 104 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(4, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,4};
yystate(3, [117|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [111|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [105|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [85|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [79|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [73|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 72 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 74, C =< 78 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 84 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 86, C =< 104 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 110 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 116 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 118 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(3, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,3};
yystate(2, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 47 ->
    yystate(65, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(2, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 58 ->
    yystate(65, Ics, Line, Tlen+1, 11, Tlen);
yystate(2, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,2};
yystate(1, [101|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [69|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 68 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 100 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 102 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,1};
yystate(0, [110|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [78|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [11|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [12|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 8 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 14, C =< 31 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 77 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 109 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 111 ->
    yystate(65, Ics, Line, Tlen+1, 12, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, TokenLine) ->
    yyaction_0(TokenLine);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, _, _, TokenLine) ->
    yyaction_2(TokenLine);
yyaction(3, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_3(TokenChars, TokenLen, TokenLine);
yyaction(4, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_4(TokenChars, TokenLen, TokenLine);
yyaction(5, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_5(TokenChars, TokenLen, TokenLine);
yyaction(6, _, _, TokenLine) ->
    yyaction_6(TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, _, _, TokenLine) ->
    yyaction_8(TokenLine);
yyaction(9, _, _, TokenLine) ->
    yyaction_9(TokenLine);
yyaction(10, _, _, _) ->
    yyaction_10();
yyaction(11, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_11(TokenChars, TokenLine);
yyaction(12, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_12(TokenChars, TokenLine);
yyaction(13, _, _, TokenLine) ->
    yyaction_13(TokenLine);
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/1}).
-file("src/nats_lexer.xrl", 35).
yyaction_0(TokenLine) ->
     { end_token, { ok, TokenLine } } .

-compile({inline,yyaction_1/1}).
-file("src/nats_lexer.xrl", 36).
yyaction_1(TokenLine) ->
     { end_token, { ping, TokenLine } } .

-compile({inline,yyaction_2/1}).
-file("src/nats_lexer.xrl", 37).
yyaction_2(TokenLine) ->
     { end_token, { pong, TokenLine } } .

-compile({inline,yyaction_3/3}).
-file("src/nats_lexer.xrl", 39).
yyaction_3(TokenChars, TokenLen, TokenLine) ->
     { end_token, { err, TokenLine,
     list_to_binary (lists : sublist (TokenChars, 6, TokenLen - 7)) } } .

-compile({inline,yyaction_4/3}).
-file("src/nats_lexer.xrl", 42).
yyaction_4(TokenChars, TokenLen, TokenLine) ->
     { end_token, { info, TokenLine, lists : sublist (TokenChars, 6, TokenLen - 7) } } .

-compile({inline,yyaction_5/3}).
-file("src/nats_lexer.xrl", 44).
yyaction_5(TokenChars, TokenLen, TokenLine) ->
     { end_token, { connect, TokenLine, lists : sublist (TokenChars, 9, TokenLen - 10) } } .

-compile({inline,yyaction_6/1}).
-file("src/nats_lexer.xrl", 45).
yyaction_6(TokenLine) ->
     { token, { msg, TokenLine } } .

-compile({inline,yyaction_7/1}).
-file("src/nats_lexer.xrl", 46).
yyaction_7(TokenLine) ->
     { token, { sub, TokenLine } } .

-compile({inline,yyaction_8/1}).
-file("src/nats_lexer.xrl", 47).
yyaction_8(TokenLine) ->
     { token, { pub, TokenLine } } .

-compile({inline,yyaction_9/1}).
-file("src/nats_lexer.xrl", 48).
yyaction_9(TokenLine) ->
     { token, { unsub, TokenLine } } .

-compile({inline,yyaction_10/0}).
-file("src/nats_lexer.xrl", 49).
yyaction_10() ->
     skip_token .

-compile({inline,yyaction_11/2}).
-file("src/nats_lexer.xrl", 50).
yyaction_11(TokenChars, TokenLine) ->
     { token, { num, TokenLine, list_to_integer (TokenChars) } } .

-compile({inline,yyaction_12/2}).
-file("src/nats_lexer.xrl", 51).
yyaction_12(TokenChars, TokenLine) ->
     { token, { arg, TokenLine, list_to_binary (TokenChars) } } .

-compile({inline,yyaction_13/1}).
-file("src/nats_lexer.xrl", 52).
yyaction_13(TokenLine) ->
     { end_token, { eol, TokenLine } } .

-file("/usr/local/Cellar/erlang/18.2.1/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 290).
